-- ------------------------------------------------------------------------------------------ --
--                                                                                            --
-- Prevod puvodnich tabulek do novych                                                         --
--                                                                                            --
-- ------------------------------------------------------------------------------------------ --

-- DULEZITE INFORMACE:
------------------------------------------------------------------------------------------------
-- V pripade, ze se budou porovnavat puvodni stavy skladu (v zazalohovane databazi, v exportu 
-- excelu), silne doporucuji na jeste neprevedenych datech spustit prepocet Mnozstvi kryte
/* ---------------------------------------------------------------------------------------------
DECLARE @IDZboSklad INT
DECLARE c CURSOR FAST_FORWARD LOCAL FOR
  SELECT ID
  FROM TabStavSkladu
OPEN c
WHILE 1=1
BEGIN
  FETCH NEXT FROM c INTO @IDZboSklad
  IF @@FETCH_STATUS <> 0 BREAK

  EXEC dbo.hp_DosleObj_UpdateStSklMnozstviKryte @IDZboSklad
END
CLOSE c
DEALLOCATE c
--------------------------------------------------------------------------------------------- */

-- Zalozeni tmp tabulky, ponese informaci o tom, zda-li doslo k uspesnemu prevodu na NZB
-- Nakonec je v ZAVERu zrusena
CREATE TABLE #NZB_Uspesne_Zapnuto ( Zapnuto BIT )
INSERT #NZB_Uspesne_Zapnuto ( Zapnuto ) VALUES ( 0 )
GO

-- ------------------------------------------------------------------------------------------ --
-- vypnuti triggeru v novych tabulkach                                                        --
-- ------------------------------------------------------------------------------------------ --
DISABLE TRIGGER dbo.ht_TabZajistKryBlokX_IUD ON dbo.TabZajistKryBlokX
GO
DISABLE TRIGGER dbo.ht_TabZajistKryPrijX_IUD ON dbo.TabZajistKryPrijX
GO
DISABLE TRIGGER dbo.ht_TabZajistKryVydX_IUD ON dbo.TabZajistKryVydX
GO
DISABLE TRIGGER dbo.ht_TabZajistKryX_DIU ON dbo.TabZajistKryX
GO

-- ------------------------------------------------------------------------------------------ --
-- kontrola verze                                                                             --
-- ------------------------------------------------------------------------------------------ --
DECLARE @Verze NVARCHAR(12), @VerzeRok INT, @VerzeMesic INT, @VerzeHeliosu INT

SELECT @Verze = VerzeEXE FROM TabHGlob

SET @VerzeRok     = CAST( SUBSTRING(@Verze, 5, 4) AS INT )
SET @VerzeMesic   = CAST( SUBSTRING(@Verze, 9, 2) AS INT )
SET @VerzeHeliosu = CAST( SUBSTRING(@Verze, 1, 2) AS INT )

IF @VerzeHeliosu = 2
BEGIN
  SELECT N'Skript lze spustit pouze na verzi 3 (iNuvio)! Operace byla zrusena.'
  GOTO ZAVER
END

IF ( @VerzeRok < 2021 ) OR
   ( @VerzeRok = 2021 AND @VerzeMesic < 9 )
BEGIN
  SELECT N'Skript lze spustit pouze na verzi 030020210900 a vy! Operace byla zrusena.'
  GOTO ZAVER
END

-- ------------------------------------------------------------------------------------------ --
-- kontrola spusteni NZB                                                                      --
-- ------------------------------------------------------------------------------------------ --
IF EXISTS(SELECT*FROM TabHGlob WHERE NZB=1)
BEGIN
  SELECT N'Priznak NZB je jiz nastaven! Operace byla zrusena.'
  GOTO ZAVER
END

-- ------------------------------------------------------------------------------------------ --
-- kontrola prazdnosti novych tabulek                                                         --
-- ------------------------------------------------------------------------------------------ --
IF EXISTS(SELECT*FROM TabZajistKryVydX) OR
   EXISTS(SELECT*FROM TabZajistKryBlokX) OR
   EXISTS(SELECT*FROM TabZajistKryPrijX) OR
   EXISTS(SELECT*FROM TabZajistKryX) OR
   EXISTS(SELECT*FROM TabZajistPriX) OR
   EXISTS(SELECT*FROM TabZajistX)
BEGIN
  SELECT N'Alespon jedna tabulka TabZajist... neni prazdna! Operace byla zrusena.'
  GOTO ZAVER
END

-- ------------------------------------------------------------------------------------------ --
--	kontrola puvodnich hlavicek a puvodnich zajistovacich tabulek                             --
-- ------------------------------------------------------------------------------------------ --
IF NOT EXISTS(SELECT*FROM TabDosleObjH02)
  IF NOT EXISTS(SELECT * FROM TabZpusobZajDObj02)
    IF NOT EXISTS(SELECT*FROM TabDosleObjH03)
	  IF NOT EXISTS(SELECT * FROM TabZpusobZajDObj03)
        GOTO ZapniNZB
  

-- ------------------------------------------------------------------------------------------ --
-- TRANSAKCE                                                                                  --
-- ------------------------------------------------------------------------------------------ --
BEGIN TRANSACTION

-- ------------------------------------------------------------------------------------------ --
-- vymazat vse, co se muze vyskytovat v novych tabulkach                                      --
-- ------------------------------------------------------------------------------------------ --
--DELETE FROM TabZajistKryVydX
--IF @@ERROR <> 0 GOTO CHYBAROLLBACK
--DELETE FROM TabZajistKryBlokX
--IF @@ERROR <> 0 GOTO CHYBAROLLBACK
--DELETE FROM TabZajistKryPrijX
--IF @@ERROR <> 0 GOTO CHYBAROLLBACK
--DELETE FROM TabZajistKryX
--IF @@ERROR <> 0 GOTO CHYBAROLLBACK
--DELETE FROM TabZajistPriX
--IF @@ERROR <> 0 GOTO CHYBAROLLBACK
--DELETE FROM TabZajistX
--IF @@ERROR <> 0 GOTO CHYBAROLLBACK



-- ------------------------------------------------------------------------------------------ --
--                                                                                            --
-- samotny proces prenosu                                                                     --
--                                                                                            --
-- ------------------------------------------------------------------------------------------ --

DECLARE @IDDObjR02 INT, @IDZajistX INT, @IDZajKry02 INT, @IDZajistKryX INT, @IDDObjR22 INT,
        @IDZajistKryBloxX INT, @MnozstviVyd NUMERIC(19,6), @Mnozstvi NUMERIC(19,6), @IDPohybu INT,
		@IDDObjR03 INT, @IDZajistX03 INT, @IDZajKry03 INT, @IDZajistKryX03 INT

-- ------------------------------------------------------------------------------------------ --
-- Penos z tabulky TabZpusobZajDObj02                                                        --
-- ------------------------------------------------------------------------------------------ --
DECLARE x CURSOR FAST_FORWARD LOCAL FOR 
SELECT r.ID
FROM TabDosleObjR02 r
  JOIN TabZpusobZajDObj02 d ON d.ID = r.ID
OPEN x
WHILE 1=1
BEGIN
  FETCH NEXT FROM x INTO @IDDObjR02
  IF @@FETCH_STATUS <> 0 BREAK

  INSERT TabZajistX( IDDObjR02, IDGPrUMZ, IDPrKVaz, IDPohybu, IDSvsSpo, GUID, DruhZajDok, MnResit, MnResitEvid, PozadDatDod, Autor, DatPorizeni, Zmenil, DatZmeny, BlokovaniEditoru, JeNovaVetaEditor)
  SELECT @IDDObjR02, NULL, NULL, NULL, NULL, GUID, 0 AS DruhZajDok, MnResit, MnResitEvid, PozadDatDod, Autor, DatPorizeni, Zmenil, DatZmeny, BlokovaniEditoru, JeNovaVetaEditor
  FROM TabZpusobZajDObj02
  WHERE ID = @IDDObjR02

  IF @@ERROR <> 0 GOTO CHYBAROLLBACK

  -- ID Z Insertu
  SET @IDZajistX = SCOPE_IDENTITY()

  -- ------------------------------------------------------------------------------------------ --
  -- Penos z tabulky TabDosleObjR22                                                            --
  -- ------------------------------------------------------------------------------------------ --
  DECLARE p CURSOR FAST_FORWARD LOCAL FOR
  SELECT ID
  FROM TabDosleObjR22
  WHERE IDZpusob = @IDDObjR02
  OPEN p
  WHILE 1=1
  BEGIN
    FETCH NEXT FROM p INTO @IDDObjR22
	IF @@FETCH_STATUS <> 0 BREAK

	INSERT TabZajistPriX( IDZajist, CisloOrg, MistoUrceni, CisloZakazky, JCBezDani, Mena, MnozstviMJZajDok, MnozstviMJZaj, MJ, PozadDatDod, ZpusobZaj, RadaDokladu, NavysitMinMn)
	SELECT @IDZajistX, CisloOrg, MistoUrceni, CisloZakazky, JCBezDani, Mena, MnozDObj, MnozVObj, MJ, PozadDatDod, ZpusobZaj, RadaDokladu, NavysitMinMn
	FROM TabDosleObjR22
	WHERE ID = @IDDObjR22

	IF @@ERROR <> 0 GOTO CHYBAROLLBACK
  END
  CLOSE p
  DEALLOCATE p

  -- ------------------------------------------------------------------------------------------ --
  -- Penos z tabulky TabZpusobZajKry02                                                            --
  -- ------------------------------------------------------------------------------------------ --
  DECLARE x2 CURSOR FAST_FORWARD LOCAL FOR
  SELECT ID
  FROM TabZpusobZajKry02
  WHERE IDZpusob = @IDDObjR02
  OPEN x2
  WHILE 1=1
  BEGIN
    FETCH NEXT FROM x2 INTO @IDZajKry02
	IF @@FETCH_STATUS <> 0 BREAK

    INSERT TabZajistKryX(IDZajist, GUID, IDPohybu, Zpusob, MnKryte, MnKryteEvid, MnRealPrijem, MnRealPrijemEv, Generovano, IDVyrPlan, IDZboSklad, Autor, DatPorizeni, Zmenil, DatZmeny)
    SELECT @IDZajistX, GUID, IDPohybu, Zpusob, MnKryte, MnKryteEvid, MnRealPrijem, MnRealPrijemEv, Generovano, IDVyrPlan, IDZboSklad, Autor, DatPorizeni, Zmenil, DatZmeny
    FROM TabZpusobZajKry02 
	WHERE ID = @IDZajKry02

	IF @@ERROR <> 0 GOTO CHYBAROLLBACK

    -- ID Z Insertu
    SET @IDZajistKryX = SCOPE_IDENTITY()

	-- ------------------------------------------------------------------------------------------ --
    -- Penos z tabulky TabDilciPrijmyDObj02                                                      --
    -- ------------------------------------------------------------------------------------------ --
    --a. zajistene prijemkou
	IF EXISTS(SELECT*FROM TabDilciPrijmyDObj02 WHERE IDZpusob = @IDZajKry02 AND IDPohybu IS NOT NULL)
	BEGIN
	  INSERT TabZajistKryPrijX( IDZajistKry, IDPohybu, Mnozstvi, MnRealPrijemEv)
	  SELECT @IDZajistKryX, IDPohybu, Mnozstvi, MnRealPrijemEv
	  FROM TabDilciPrijmyDObj02
	  WHERE IDZpusob = @IDZajKry02

	  IF @@ERROR <> 0 GOTO CHYBAROLLBACK
	END

	--b. ty ktere jsou blokace
	IF EXISTS(SELECT*FROM TabDilciPrijmyDObj02 WHERE IDZpusob = @IDZajKry02 AND IDPohybu IS NULL)
	BEGIN
	  INSERT TabZajistKryBlokX( IDZajistKry, Mnozstvi)
	  SELECT @IDZajistKryX, Mnozstvi
	  FROM TabDilciPrijmyDObj02
	  WHERE IDZpusob = @IDZajKry02

	  IF @@ERROR <> 0 GOTO CHYBAROLLBACK

	  -- ID Z Insertu
      SET @IDZajistKryBloxX = SCOPE_IDENTITY()

	  -- ------------------------------------------------------------------------------------------ --
      -- Doplnn do TabZajistKryVydX do ve blokac                                               --
      -- ------------------------------------------------------------------------------------------ --
	  SELECT @Mnozstvi = Mnozstvi FROM TabZajistKryBlokX WHERE ID = @IDZajistKryBloxX
	  IF @Mnozstvi > 0
	  BEGIN
	    DECLARE c CURSOR FAST_FORWARD LOCAL FOR
          SELECT N.IDNavazPol, N.MnozstviPohybu
		  FROM TabZajistKryBlokX B
            JOIN TabZajistKryX Z ON Z.ID = B.IDZajistKry
            JOIN TabZajistX  D ON D.ID = Z.IDZajist
            -- zatim navazany pouze Dosle objednavky a nerealizovane vydejky se spravnym IDZboSklad zajistenym stavem skladu...
            JOIN TabDosleObjNavazDok02 N ON N.IDDoslaObjR = D.IDDObjR02 AND N.DruhPohybuZbo IN (2,4) AND N.Realizovano = 0
			JOIN TabPohybyZbozi        P ON P.ID = N.IDNavazPol AND P.IDZboSklad = Z.IDZboSklad
          WHERE B.ID = @IDZajistKryBloxX
            -- Vyjma vydejek, ktere jsou uz navazany
            AND NOT EXISTS(SELECT*FROM TabZajistKryVydX WHERE IDZajistKry = Z.ID AND IDPohybu = N.IDNavazPol)
        OPEN c
        WHILE 1=1
        BEGIN
          FETCH NEXT FROM c INTO @IDPohybu, @MnozstviVyd
          IF @@FETCH_STATUS <> 0 BREAK

          -- postupne vykryvam vsechny vydejky do vyse predaneho Mnozstvi
          IF @MnozstviVyd > @Mnozstvi
            SET @MnozstviVyd = @Mnozstvi

          -- Insert
          INSERT TabZajistKryVydX (IDZajistKry, IDPohybu, Mnozstvi)
          SELECT @IDZajistKryX, @IDPohybu, @MnozstviVyd

          SET @Mnozstvi = @Mnozstvi - @MnozstviVyd

          IF @Mnozstvi <= 0 BREAK
        END
        CLOSE c
        DEALLOCATE c
	  END
	END
  END
  CLOSE x2
  DEALLOCATE x2
END
CLOSE x
DEALLOCATE x



-- ------------------------------------------------------------------------------------------ --
-- Penos z tabulky TabZpusobZajDObj03                                                        --
-- ------------------------------------------------------------------------------------------ --
DECLARE xArchiv CURSOR FAST_FORWARD LOCAL FOR 
SELECT r.ID
FROM TabDosleObjR03 r
  JOIN TabZpusobZajDObj03 d ON d.ID = r.ID
OPEN xArchiv
WHILE 1=1
BEGIN
  FETCH NEXT FROM xArchiv INTO @IDDObjR03
  IF @@FETCH_STATUS <> 0 BREAK

  INSERT TabZajistX03( IDDObjR03, IDGPrUMZ, GUID, DruhZajDok, MnResit, MnResitEvid, PozadDatDod, Autor, DatPorizeni, Zmenil, DatZmeny, BlokovaniEditoru, JeNovaVetaEditor)
  SELECT @IDDObjR03, NULL, GUID, 0 AS DruhZajDok, MnResit, MnResitEvid, PozadDatDod, Autor, DatPorizeni, Zmenil, DatZmeny, BlokovaniEditoru, JeNovaVetaEditor
  FROM TabZpusobZajDObj03
  WHERE ID = @IDDObjR03

  IF @@ERROR <> 0 GOTO CHYBAROLLBACK

  -- ID Z Insertu
  SET @IDZajistX03 = SCOPE_IDENTITY()

  -- ------------------------------------------------------------------------------------------ --
  -- Penos z tabulky TabZpusobZajKry03                                                         --
  -- ------------------------------------------------------------------------------------------ --
  DECLARE x3 CURSOR FAST_FORWARD LOCAL FOR
  SELECT ID
  FROM TabZpusobZajKry03
  WHERE IDZpusob = @IDDObjR03
  OPEN x3
  WHILE 1=1
  BEGIN
    FETCH NEXT FROM x3 INTO @IDZajKry03
	IF @@FETCH_STATUS <> 0 BREAK

    INSERT TabZajistKryX03(IDZajist, GUID, IDPohybu, Zpusob, MnKryte, MnKryteEvid, MnRealPrijem, MnRealPrijemEv, Generovano, IDVyrPlan, IDZboSklad, Autor, DatPorizeni, Zmenil, DatZmeny)
    SELECT @IDZajistX03, GUID, IDPohybu, Zpusob, MnKryte, MnKryteEvid, MnRealPrijem, MnRealPrijemEv, Generovano, IDVyrPlan, IDZboSklad, Autor, DatPorizeni, Zmenil, DatZmeny
    FROM TabZpusobZajKry03
	WHERE ID = @IDZajKry03

	IF @@ERROR <> 0 GOTO CHYBAROLLBACK

    -- ID Z Insertu
    SET @IDZajistKryX03 = SCOPE_IDENTITY()

	-- ------------------------------------------------------------------------------------------ --
    -- Penos z tabulky TabDilciPrijmyDObj03                                                      --
    -- ------------------------------------------------------------------------------------------ --
    --a. zajistene prijemkou
	IF EXISTS(SELECT*FROM TabDilciPrijmyDObj03 WHERE IDZpusob = @IDZajKry03 AND IDPohybu IS NOT NULL)
	BEGIN
	  INSERT TabZajistKryPrijX03( IDZajistKry, IDPohybu, Mnozstvi, MnRealPrijemEv)
	  SELECT @IDZajistKryX03, IDPohybu, Mnozstvi, MnRealPrijemEv
	  FROM TabDilciPrijmyDObj03
	  WHERE IDZpusob = @IDZajKry03

	  IF @@ERROR <> 0 GOTO CHYBAROLLBACK
	END

	--b. blokace v archivu nejsou	
  END
  CLOSE x3
  DEALLOCATE x3
END
CLOSE xArchiv
DEALLOCATE xArchiv

-- ------------------------------------------------------------------------------------------ --
-- vymazat vse co je v puvodnich tabulkach                                                    --
--   - v pripade, ze by se provadela zmena typu dokladu, neprosla by kontrola na vazby        --
--     v tabulkach                                                                            --
-- ------------------------------------------------------------------------------------------ --
DELETE FROM TabDilciPrijmyDObj02
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
DELETE FROM TabDosleObjR22
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
DELETE FROM TabZpusobZajKry02
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
DELETE FROM TabZpusobZajDObj02
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
DELETE FROM TabDilciPrijmyDObj03
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
DELETE FROM TabZpusobZajKry03
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
DELETE FROM TabZpusobZajDObj03
IF @@ERROR <> 0 GOTO CHYBAROLLBACK



-- ------------------------------------------------------------------------------------------ --
-- uprava stavu skladu                                                                             --
-- ------------------------------------------------------------------------------------------ --
-- Blokace - Nejdrive vse nastavit na 0
UPDATE TabStavSkladu SET BlokovanoProDObj = 0
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
-- Blokace - Potom dopln pocty z blokaci
UPDATE S
SET S.BlokovanoProDObj   = Z.MnozstviZbozi
FROM TabStavSkladu S
  JOIN TabKmenZbozi AS K ON K.ID = S.IDKmenZbozi
  JOIN TabStrom     AS T ON T.Cislo = S.IDSklad
  JOIN (
 	SELECT IDZboSklad, DruhZajDok, SUM(Mnozstvi) AS MnozstviZbozi
    FROM (
	      SELECT KI.IDZboSklad, DI.DruhZajDok, I.Mnozstvi
          FROM TabZajistKryBlokX I
          JOIN TabZajistKryX KI ON KI.ID = I.IDZajistKry
          JOIN TabZajistX    DI ON DI.ID = KI.IDZajist
          WHERE KI.Zpusob = 1
		  ) T
    GROUP BY IDZboSklad, DruhZajDok) Z ON Z.IDZboSklad = S.ID AND Z.DruhZajDok = 0
WHERE Z.MnozstviZbozi <> 0 AND K.Sluzba <> 1 AND T.DruhSkladu <> 0
IF @@ERROR <> 0 GOTO CHYBAROLLBACK

-- Blokace vydejky - Nejdrive vse nastavit na 0
UPDATE TabStavSkladu SET BlokovanoVydProDObj = 0
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
-- Blokace vydejky - Potom dopln pocty z blokaci
UPDATE S
SET S.BlokovanoVydProDObj = Z.MnozstviZbozi
FROM TabStavSkladu S
  JOIN TabKmenZbozi AS K ON K.ID = S.IDKmenZbozi
  JOIN TabStrom     AS T ON T.Cislo = S.IDSklad
  JOIN (
 	SELECT IDZboSklad, DruhZajDok, SUM(Mnozstvi) AS MnozstviZbozi
    FROM (
	      SELECT KI.IDZboSklad, DI.DruhZajDok, I.Mnozstvi
          FROM TabZajistKryVydX I
          JOIN TabZajistKryX KI ON KI.ID = I.IDZajistKry
          JOIN TabZajistX    DI ON DI.ID = KI.IDZajist
          WHERE KI.Zpusob = 1
		  ) T
    GROUP BY IDZboSklad, DruhZajDok) Z ON Z.IDZboSklad = S.ID AND Z.DruhZajDok = 0
WHERE Z.MnozstviZbozi <> 0 AND K.Sluzba <> 1 AND T.DruhSkladu <> 0
IF @@ERROR <> 0 GOTO CHYBAROLLBACK

-- Mnozstvi k vyrizeni
EXEC dbo.hp_NZB_DosleObj_AktualizujMnozKVyrizeni NULL, 1
IF @@ERROR <> 0 GOTO CHYBAROLLBACK  
-- Mnozstvi kryte
DECLARE @IDZboSklad INT
DECLARE c CURSOR FAST_FORWARD LOCAL FOR
  SELECT ID
  FROM TabStavSkladu
OPEN c
WHILE 1=1
BEGIN
  FETCH NEXT FROM c INTO @IDZboSklad
  IF @@FETCH_STATUS <> 0 BREAK

  EXEC dbo.hp_NZB_UpdateStSklMnozstviKryte 0, @IDZboSklad
  IF @@ERROR <> 0 GOTO CHYBAROLLBACK
END
CLOSE c
DEALLOCATE c



-- ------------------------------------------------------------------------------------------ --
--                                                                                            --
-- KONEC TRANSAKCE                                                                            --
--                                                                                            --
-- ------------------------------------------------------------------------------------------ --
COMMIT




-- *********************************************************************************************
ZapniNZB:

-- ------------------------------------------------------------------------------------------ --
-- zapnuti NZB                                                                                --
-- ------------------------------------------------------------------------------------------ --
UPDATE TabHGlob SET NZB = 1
IF @@ERROR <> 0 GOTO CHYBAROLLBACK
IF OBJECT_ID(N'tempdb..#NZB_Uspesne_Zapnuto') IS NOT NULL
  UPDATE #NZB_Uspesne_Zapnuto SET Zapnuto = 1

GOTO ZAVER



CHYBAROLLBACK:
ROLLBACK





-- *********************************************************************************************
ZAVER:


-- ------------------------------------------------------------------------------------------ --
-- zapnuti vypnutych triggeru                                                                 --
-- ------------------------------------------------------------------------------------------ --
GO
ENABLE TRIGGER dbo.ht_TabZajistKryBlokX_IUD ON dbo.TabZajistKryBlokX
GO
ENABLE TRIGGER dbo.ht_TabZajistKryPrijX_IUD ON dbo.TabZajistKryPrijX
GO
ENABLE TRIGGER dbo.ht_TabZajistKryVydX_IUD ON dbo.TabZajistKryVydX
GO
ENABLE TRIGGER dbo.ht_TabZajistKryX_DIU ON dbo.TabZajistKryX
GO


IF OBJECT_ID(N'tempdb..#NZB_Uspesne_Zapnuto') IS NOT NULL
BEGIN
  IF EXISTS(SELECT*FROM #NZB_Uspesne_Zapnuto WHERE Zapnuto = 1)
  BEGIN

    -- ------------------------------------------------------------------------------------------ --
    -- prepocet hlavicek DO                                                                       --
    -- ------------------------------------------------------------------------------------------ --
    EXEC dbo.hp_DosleObj_UpdateStavKrytiHlavicky_Servis  

    -- ------------------------------------------------------------------------------------------ --
    -- hlaseni                                                                                    --
    -- ------------------------------------------------------------------------------------------ --
    SELECT N'Prevod dokoncen OK.'

  END

  -- Zruseni tmp tabulky
  DROP TABLE #NZB_Uspesne_Zapnuto
END